local MODNAME = "ReadyCheckReminder"
local ACTIVATED_ICON = "Interface\\Icons\\Inv_scroll_10"
local DEACTIVATED_ICON = "Interface\\Icons\\Inv_scroll_05"

local addon = LibStub( "AceAddon-3.0" ):NewAddon( MODNAME, "AceEvent-3.0", "AceConsole-3.0" )

addon:RegisterChatCommand("rrm", "SlashProcessorFunc")

local AceGUI = LibStub("AceGUI-3.0")

local LSM = LibStub("LibSharedMedia-3.0")

local defaults = {
  profile = {
    setting = true,
  }
}

local moverBackdrop = {
  bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
}

function addon:OnInitialize()

    self.data = LibStub("AceDB-3.0"):New("rrData", defaults)

    self.db = self.data.profile

    if self.db.diag_text==nil then self.db.diag_text = "" end

    if self.db.font_path==nil then self.db.font_path = "Fonts\\ARIALN.TTF" end
	
	if self.db.font_size == nil then self.db.font_size = 11 end
	
	if self.db.msg_x_offset == nil then self.db.msg_x_offset = 0 end

	if self.db.msg_y_offset == nil then self.db.msg_y_offset = 0 end
	
	if self.db.msg_point == nil then self.db.msg_point = "CENTER" end

    smf = CreateFrame("ScrollingMessageFrame","rrSMF",UIParent)

    smf:SetWidth(128) -- Set these to whatever height/width is needed 
    smf:SetHeight(64) -- for your Texture

    smf:SetPoint(self.db.msg_point,self.db.msg_x_offset,self.db.msg_y_offset)
    smf:SetJustifyH("LEFT")
    smf:SetMaxLines(30)
    smf:SetFading(true)
    smf:SetFadeDuration(3)
    smf:SetTimeVisible(30)

    smf:SetClampedToScreen(true)
    
	smf:SetToplevel(true)
    smf:SetMovable(false)
    smf:EnableMouse(false)
	--smf:SetResizable(true)

	smf:SetScript("OnMouseDown", function(self, button)
		if button == "LeftButton" and not self.isMoving then
			self:StartMoving();
			self.isMoving = true;
		end
	end)

	smf:SetScript("OnMouseUp", function(self, button)
		if button == "LeftButton" and self.isMoving then
			self:StopMovingOrSizing();
			self.isMoving = false;	

			addon:SavePoint()
		end
	end)

	smf:SetScript("OnHide", function(self)
		if ( self.isMoving ) then
			self:StopMovingOrSizing();
			self.isMoving = false;
		end
	end)
	
	self:RegisterEvent("READY_CHECK", "ShowPrompt")
end

function addon:ToggleMoveMessageFrame(flag)

  if flag == true then
    smf:SetBackdrop(moverBackdrop)
    smf:SetMovable(true)
    smf:EnableMouse(true)
	 
   else
     smf:SetBackdrop(nil)
     smf:SetMovable(false)
     smf:EnableMouse(false)
     --smf:SetResizable(false) 	 
   end
end

function addon:SavePoint()

			local point, relFrame, relPoint, xOffset, yOffset = smf:GetPoint()
			self.db.msg_x_offset = xOffset
			self.db.msg_y_offset = yOffset
			self.db.msg_point = point
			
end

function addon:SlashProcessorFunc(input)
  -- Process the slash command ('input' contains whatever follows the slash command)
  addon:ShowMenu()
end

function addon:ShowPrompt()

    local _, instanceType, difficulty, _, maxPlayers, playerDifficulty, isDynamicInstance = GetInstanceInfo()
    local lfr=0
    if IsPartyLFG() and IsInLFGDungeon() and difficulty == 2 and instanceType == "raid" and maxPlayers == 25 then
      lfr=1
    end

	if lfr==0 then	
	 smf:SetFont(self.db.font_path, self.db.font_size)
	 
	 smf:Clear()
	 
	 local entries = { strsplit(",",self.db.diag_text) }
	 
	 for i,v in pairs(entries) do
	  if #v > 0 then 
        smf:AddMessage(strconcat(i, " ", v))
      end
	 end

	end
end

function addon:ShowMenu()

-- Create a container frame
	local f = AceGUI:Create("Frame")
	f:SetCallback("OnClose",function(widget) AceGUI:Release(widget) end)
	f:SetTitle("Ready Check Reminder Options")
	--f:SetStatusText("Status Bar")
	f:SetLayout("Flow")

--Edit Box
	local editbox = AceGUI:Create("EditBox")
	editbox:SetLabel("Ready Check Text:")
	editbox:SetText(self.db.diag_text)
	editbox:SetWidth(500)
	editbox:SetCallback("OnEnterPressed", function(widget, event, text) self.db.diag_text = text end)
	f:AddChild(editbox)

    local fontGroup = AceGUI:Create("InlineGroup")
	fontGroup:SetCallback("OnClose",function(widget) AceGUI:Release(widget) end)
    fontGroup:SetTitle("Font Settings")
    fontGroup:SetFullWidth(true)
	fontGroup:SetLayout("Flow")
    


--Font Dropdown
	local fonts = LSM:HashTable("font")

-- If you're using AceGUI-3.0 directly;
	local dropdown = AceGUI:Create("LSM30_Font")
	--dropdown:SetLabel("Font")
	dropdown:SetList(fonts, nil)
	dropdown:SetCallback("OnValueChanged", function(info,event, value)
		self.db.font_path = fonts[value]
		dropdown:SetValue(value)
	end)

--Set Default
	for i, v in pairs(fonts) do
		if v == self.db.font_path then
			dropdown:SetValue(i)
			break
		end
	end

	fontGroup:AddChild(dropdown)

	local fontSize = AceGUI:Create("EditBox")
	fontSize:SetText(self.db.font_size)
	fontSize:SetWidth(135)
	fontSize:SetCallback("OnEnterPressed", function(widget, event, text) self.db.font_size = text end)
	
	fontGroup:AddChild(fontSize)
	
	local colorPicker = AceGUI:Create("ColorPicker")
	colorPicker:SetCallback("OnValueChanged", function(r,g,b,a) 
	    print(r, " ", g, " " , b, " ", a)
		colorPicker:SetColor(r,g,b,a)
	end)
	colorPicker:SetCallback("OnValueConfirmed", function(self, event, r,g,b,a) 
		smf:SetTextColor(r,g,b,a)
	end)
	
	
	fontGroup:AddChild(colorPicker)
	
	f:AddChild(fontGroup)

	local button = AceGUI:Create("Button")
	button:SetText("Test")
	button:SetCallback("OnClick",function() addon:ShowPrompt() end)
	
	f:AddChild(button)
	
	local unlockButton = AceGUI:Create("Button")
	unlockButton:SetText("UnLock")
	unlockButton:SetCallback("OnClick",function() addon:ToggleMoveMessageFrame(true) end)
	
	f:AddChild(unlockButton)

	local lockButton = AceGUI:Create("Button")
	lockButton:SetText("Lock")
	lockButton:SetCallback("OnClick",function() addon:ToggleMoveMessageFrame(false) end)
	
	f:AddChild(lockButton)

	
end